Learn R Programming

ILS (version 0.1.0)

Grubbs.test: Function to compute the Grubbs test statistic.

Description

Function to estimate the Grubbs test statistic.

Usage

Grubbs.test(x, ...)
"Grubbs.test"(x, var.index = 1, replicate.index = 2, material.index = 3, laboratory.index = 4, data.name = NULL, alpha = 0.05, ...)
"Grubbs.test"(x, alpha = 0.05, ...)

Arguments

x
an R object (used to select the method). See details.
...
arguments passed to or from methods.
var.index
Scalar with the column number corresponding to the observed variable (the critical to quality variable). Alternatively, a string with the name of a quality variable can be provided.
replicate.index
Scalar with the column number corresponding to the index each replicate.
material.index
Scalar corresponding to the replicated number.
laboratory.index
Scalar that defines the index number of each laboratory.
data.name
String specifying the name of the variable which appears on the plots. If name is not provided, it is retrieved from the object.
alpha
The significance level (0.05 for default)

References

Wilrich Peter-T. (2013), Critical values of Mandel's h and k, the Grubbs and the Cochram test statistic. Asta-Advances in Statistical Analysis, 97(1):1-10.

ASTM E 691 (1999), Standard practice for conducting an interlaboratory study to determine the precision of a test method. American Society for Testing and Materials. West Conshohocken, PA, USA.

Examples

Run this code

library(ILS)
data(Glucose)
Glucose.qcd <- lab.qcd(Glucose)
str(Glucose.qcd)
Grubbs.test(Glucose.qcd)

Run the code above in your browser using DataLab