Learn R Programming

ILS (version 0.1.0)

k.fqcs: This function is used to compute the FDA Mandel's k statistic

Description

It develops an object of 'k.fqcs' class to perform statistical quality control analysis. This function is used to compute the functional approach of Mandel's k statistic. It is specifically designed to deal with experimental data results defined by curves such as thermograms and spectra.

Usage

k.fqcs(x, ...)
"k.fqcs"(x, argvals = NULL, rangeval = NULL, ...)
"k.fqcs"(x, ...)

Arguments

x
A (m x p) matrix or data-frame. Alternatively an (m x p x n) array. The m parameter is the number of curves, p defines the number of points observed in each curve, and n is the number of replicates.
...
Arguments passed to or from methods.
argvals
Argvals, by default: 1:p.
rangeval
Range of discretization points, by default: range(argvals).

References

Febrero-Bande, M. and Oviedo, M. (2012), "Statistical computing in functional data analysis: the R package fda.usc". Journal of Statistical Software 51 (4), 1-28.

Cuevas A., Febrero-Bande, M. and Fraiman, R. (2006), "On the use of the bootstrap for estimating functions with functional data". Computational Statistics & Data Analysis 51, 2, 1063-1074.

Naya, S., Tarrio-Saavedra. J., Lopez- Beceiro, J., Francisco Fernandez, M., Flores, M. and Artiaga, R. (2014), "Statistical functional approach for interlaboratory studies with thermal data". Journal of Thermal Analysis and Calorimetry, 118,1229-1243.

Examples

Run this code
library(ILS)
data(TG)
delta <- seq(from = 40 ,to = 850 ,length.out = 1000 )
curves.fqcd <- lab.fqcd(TG, argvals = delta)
fk <- k.fqcs(curves.fqcd)
p <- fk$p
xlab <- "Temperature (Grade Celsius)"
ylab <- "Mass (%)"
main <- "Functional ki  Estimation"
plot(fk,main = main, xlab = xlab, ylab = ylab, ylim=c(0,3),col=1:p)
legend(10,3,paste("Lab",1:p),
      col=1:p,lty=1,lwd=2,cex=0.7)

Run the code above in your browser using DataLab