Learn R Programming

ILS (version 0.1.0)

lab.aov: Function to compute the AOV

Description

Function to compute the analysis of variance of ILS data, taking into account the laboratories and material factors.

Usage

lab.aov(x, ...)
"lab.aov"(x, var.index = 1, replicate.index = 2, material.index = 3, laboratory.index = 4, data.name = NULL, level = 0.95, plot = FALSE, pages = 0, ...)
"lab.aov"(x, level = 0.95, plot = FALSE, pages = 0, ...)

Arguments

x
Object lab.qcd.
...
Arguments passed to or from methods.
var.index
Scalar with the column number corresponding to the observed variable (the critical to quality variable). Alternatively, a string with the name of a quality variable can be provided.
replicate.index
Scalar with the column number corresponding to the index each replicate.
material.index
Scalar corresponding to the replicated number.
laboratory.index
Scalar that defines the index number of each laboratory.
data.name
String specifying the name of the variable which appears on the plots. If name is not provided, it is retrieved from the object.
level
Requested confidence level (0.95 by default)
plot
If TRUE, confidence intervals are plot.
pages
By default 0, it indicates the number of pages over which to spread the output. For example, if pages=1, all terms will be plotted on one page with the layout performed automatically. If pages=0, one plot will be displayed by each tested material.

References

WHothorn T., Bretz, F., and Westfall, P. (2008), Simultaneous inference in general parametric models. Biometrical Journal, 50(3):346-363.

Heyden, Y., Smeyers-Verbeke, J. (2007), Set-up and evaluation of interlaboratory studies. J. Chromatogr. A, 1158:158-167.

Examples

Run this code
## Not run: 
# library(ILS)
# data(Glucose)
# Glucose.qcd <- lab.qcd(Glucose)
# str(Glucose.qcd)
# lab.aov(Glucose.qcd,level = 0.95, plot = TRUE, pages = 1)
# ## End(Not run)

Run the code above in your browser using DataLab