Learn R Programming

ILS (version 0.1.0)

lab.fqcd: Functional Quality Control Data

Description

It Creates an object of class 'lab.fqcd' to perform statistical quality control. This object is used to plot functional data.

Usage

lab.fqcd(x, argvals = NULL, rangeval = NULL)

Arguments

x
A (m x p) matrix or data-frame. Alternatively an (m x p x n) array. The m parameter is the number of curves, p defines the number of points observed in each curve, and n is the number of replicates.
argvals
Argvals, by default: 1:p.
rangeval
Range of discretization points, by default: range(argvals).

References

Febrero-Bande, M. and Oviedo, M. (2012), "Statistical computing in functional data analysis: the R package fda.usc". Journal of Statistical Software 51 (4), 1-28.

Naya, S., Tarrio-Saavedra. J., Lopez- Beceiro, J., Francisco Fernandez, M., Flores, M. and Artiaga, R. (2014), "Statistical functional approach for interlaboratory studies with thermal data". Journal of Thermal Analysis and Calorimetry, 118,1229-1243.

Examples

Run this code
## Not run: 
# library(ILS)
# data(TG) 
# delta <- seq(from = 40 ,to = 850 ,length.out = 1000 )
# curves.fqcd <- lab.fqcd(TG, argvals = delta)
# windows()
# xlab <- "Temperature (0C)"
# ylab <- "Mass (%)"
# main <- "TG curves obtained from calcium oxalate"
# p <- curves.fqcd$p
# col <- terrain.colors(p)
# plot(x = curves.fqcd, main, xlab, ylab,legend = FALSE,col = col)
# legend(45,70,c(paste("Lab",c(1:7))),
#       col = col,lty = 1, lwd = c(rep(1,7),2), cex = 0.7)
#       ## End(Not run)

Run the code above in your browser using DataLab