Learn R Programming

ILS (version 0.1.0)

lab.fqcs: It developes an object of class 'lab.fqcs'

Description

Create an object of class 'lab.fqcs' to perform statistical quality control. This function is used to compute requested FDA.

Usage

lab.fqcs(x, ...)
"lab.fqcs"(x, argvals = NULL, rangeval = NULL, ...)
"lab.fqcs"(x, ...)
"print"(x, ...)
"summary"(object, ...)

Arguments

x
A lab.fqcs object for which a print is desired.
...
Arguments passed to or from methods.
argvals
Argvals, by default: 1:p.
rangeval
Range of discretization points, by default: range(argvals).
object
A lab.fqcs object for which a summary is desired.

References

Febrero-Bande, M. and Oviedo, M. (2012), "Statistical computing in functional data analysis: the R package fda.usc". Journal of Statistical Software 51 (4), 1-28.

Cuevas A., Febrero-Bande, M. and Fraiman, R. (2006), "On the use of the bootstrap for estimating functions with functional data". Computational Statistics & Data Analysis 51, 2, 1063-1074.

Naya, S., Tarrio-Saavedra. J., Lopez- Beceiro, J., Francisco Fernandez, M., Flores, M. and Artiaga, R. (2014), "Statistical functional approach for interlaboratory studies with thermal data". Journal of Thermal Analysis and Calorimetry, 118,1229-1243.

Examples

Run this code
## Not run: 
# library(ILS)
# data(TG)
# delta <- seq(from = 40 ,to = 850 ,length.out = 1000 )
# curves.fqcd <- lab.fqcd(TG, argvals = delta)
# p <- curves.fqcd$p
# curves.fqcs <- lab.fqcs(curves.fqcd)
# summary(curves.fqcs)
# names(curves.fqcs)
# 
# ##### Statistical Functional
# windows(20,10)
# xlab <- "Temperature (C)"
# ylab <- "Mass (%)"
# main <- "Statistical Functional"
# col <- 1:p
# ## End(Not run)

Run the code above in your browser using DataLab