Learn R Programming

ILS (version 0.1.0)

lab.qcd: Quality Control Data

Description

It creates a 'lab.qcd' class object to perform the interlaboratory study. This object is used to plot ILS data and more.

Usage

lab.qcd(data, var.index = 1, replicate.index = 2, material.index = 3, laboratory.index = 4, data.name = NULL)

Arguments

data
Matrix or data-frame that contains the data, replicate index, type of material, and the laboratory.
var.index
Scalar with the column number corresponding to the observed variable (the critical to quality variable). Alternatively, a string with the name of a quality variable can be provided.
replicate.index
Scalar with the column number corresponding to the index each replicate.
material.index
Scalar corresponding to the replicated number.
laboratory.index
Scalar that defines the index number of each laboratory.
data.name
String specifying the name of the variable which appears on the plots. If name is not provided, it is retrieved from the object.

Examples

Run this code
library(ILS)
data(Glucose)
Glucose.qcd <- lab.qcd(Glucose)
str(Glucose.qcd)
summary(Glucose.qcd)

Run the code above in your browser using DataLab