Learn R Programming

ILS (version 0.1.0)

plot.lab.fqcs: Plotting method for 'lab.fqcs' objects

Description

Generic function to plot objects of 'lab.fqcs' class. Results of functional ILS studies are graphically shown.

Usage

"plot"(x, main = NULL, xlab = NULL, ylab = NULL, ylim = NULL, x.co = NULL, y.co = NULL, legend = TRUE, col = NULL, ...)

Arguments

x
Object functional data or a list with objects of functional data type
main
Main title for the plot
xlab
Title for the x axis
ylab
Title for the y axis
ylim
The y limits of the plot
x.co
It speficies the x co-ordinates to be used to place a legend.
y.co
It specifies the y co-ordinates to be used to place a legend.
legend
Logical argument. Default is TRUE then The legend default is used.
col
Color specifications
...
arguments to be passed to or from methods

References

Febrero-Bande, M. and Oviedo, M. (2012), "Statistical computing in functional data analysis: the R package fda.usc". Journal of Statistical Software 51 (4), 1-28.

Naya, S., Tarrio-Saavedra. J., Lopez- Beceiro, J., Francisco Fernandez, M., Flores, M. and Artiaga, R. (2014), "Statistical functional approach for interlaboratory studies with thermal data". Journal of Thermal Analysis and Calorimetry, 118,1229-1243.

Examples

Run this code
library(ILS)
data(TG)
delta <- seq(from = 40 ,to = 850 ,length.out = 1000 )
curves.fqcd <- lab.fqcd(TG, argvals = delta)
curves.fqcs <- lab.fqcs(curves.fqcd)
summary(curves.fqcs)
names(curves.fqcs)
class(curves.fqcs$mean.i)
xlab <- "Temperature/ C"
ylab <- "Mass/ %"
main <- "Functional Mean Estimation by Laboratory"
p <- dim(curves.fqcd$curves)[3]
col <- 1:p
plot(curves.fqcs$mean.i,main = main, xlab = xlab, ylab = ylab, col = col,legend = FALSE)
legend(45,70,paste("Lab",1:p),
      col = col,lty = 1,lwd = 2,cex = 0.7)

Run the code above in your browser using DataLab