Scalar with the column number corresponding to the observed variable (the critical to quality variable).
Alternatively, a string with the name of a quality variable can be provided.
replicate.index
Scalar with the column number corresponding to the index each replicate.
material.index
Scalar corresponding to the replicated number.
laboratory.index
Scalar that defines the index number of each laboratory.
data.name
String specifying the name of the variable which appears on the plots.
If name is not provided, it is retrieved from the object.
level
Requested confidence level (0.95 by default)
plot
If TRUE, confidence intervals are plot.
pages
By default 0, it indicates the number of pages over which to spread the output. For example,
if pages=1, all terms will be plotted on one page with the layout performed automatically.
If pages=0, one plot will be displayed by each tested material.
References
WHothorn T., Bretz, F., and Westfall, P. (2008), Simultaneous inference in general parametric models.
Biometrical Journal, 50(3):346-363.
Heyden, Y., Smeyers-Verbeke, J. (2007), Set-up and evaluation of interlaboratory studies. J. Chromatogr. A, 1158:158-167.