Arguments
data
Matrix or data-frame that contains the data, replicate index, type of material, and the laboratory.
var.index
Scalar with the column number corresponding to the observed variable (the critical to quality variable).
Alternatively, a string with the name of a quality variable can be provided.
replicate.index
Scalar with the column number corresponding to the index each replicate.
material.index
Scalar corresponding to the replicated number.
laboratory.index
Scalar that defines the index number of each laboratory.
data.name
String specifying the name of the variable which appears on the plots.
If name is not provided, it is retrieved from the object.