lab.qcs: Create an object of class 'lab.qcs' to perform statistical quality control.
This function is used to compute statistics required for plotting Statitics
Description
It develops an object of lab.qcs-codelinkclass to perform statistical quality control.
This function is used to compute the requested statistics to be summarized and ploted.